/*
 * version.h
 *
 * Version number header file for PWLib
 *
 * Copyright (c) 1993-2000 Equivalence Pty. Ltd.
 *
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
 * the License for the specific language governing rights and limitations
 * under the License.
 *
 * The Original Code is Portable Windows Library.
 *
 * The Initial Developer of the Original Code is Equivalence Pty. Ltd.
 *
 * Contributor(s): ______________________________________.
 */

#ifndef _PWLib_VERSION_H
#define _PWLib_VERSION_H



/* WARNING: You MUST NOT add any comments to the #defines which follow
   or add extra commented out #defines as this will confuse the parser
   which extracts the version numbers
 */

#define MAJOR_VERSION 1
#define MINOR_VERSION 8
#define BUILD_TYPE    ReleaseCode
#define BUILD_NUMBER 7


#endif  // _PWLib_VERSION_H


// End of File ///////////////////////////////////////////////////////////////
